.. sinabs-dynapcnn documentation master file, created by
   sphinx-quickstart on Fri Jun 12 16:48:59 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to sinabs-dynapcnn's documentation!
===========================================

.. image:: https://codecov.io/gl/synsense/sinabs-dynapcnn/branch/master/graph/badge.svg?token=TJJJBJTHWK 
 :target: https://codecov.io/gl/synsense/sinabs-dynapcnn
   
This `sinabs` plugin enables porting sinabs models to chips and dev-kits with DYNAP-CNN technology.

DYNAP-CNN/Speck DevKits
-----------------------

- :doc:`Overview of the devkits<getting_started/overview>`.

.. image:: ./_static/devkits_images/dynapcnn_devkit.png
   :width: 366
   :height: 312
   :target: ./getting_started/index.html
.. image:: ./_static/devkits_images/speck_devkit.png
   :width: 366
   :height: 312
   :target: ./getting_started/index.html
.. image:: ./_static/devkits_images/speck_module.png
   :width: 366
   :height: 312
   :target: ./getting_started/index.html
.. image:: ./_static/devkits_images/speck_module_devkit.png
   :width: 366
   :height: 312
   :target: ./getting_started/index.html

Table of contents
-----------------
.. toctree::
   :maxdepth: 2

   installation
   getting_started/index
   the_basics
   advanced_concepts
   dangers
   faqs/index
   api/api.rst
   development
   contact_us
   change_log


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
